@@ -45,7 +45,7 @@ let download_sources () =
            (Benl_compression.extension !Benl_clflags.preferred_compression_format)
          in
          if !Benl_clflags.dry_run then p "Would download %s\n" url;
-         let cmd = sprintf "{ curl %s %s | %s >> %s; }"
+         let cmd = sprintf "{ curl -L %s %s | %s >> %s; }"
            wquiet
            (escape_for_shell url)
            (Benl_compression.display_tool !Benl_clflags.preferred_compression_format)
@@ -63,7 +63,7 @@ let download_sources () =
     if r <> 0 then
       raise (Curl_error r)
     else
-      ignore (Sys.command (sprintf "rm -f %s" tmp))
+      FileUtil.rm ~force:FileUtil.Force [tmp]
   end;;
 
 let download_binaries arch =
@@ -82,7 +82,7 @@ let download_binaries arch =
            (Benl_compression.extension !Benl_clflags.preferred_compression_format)
          in
          if !Benl_clflags.dry_run then p "Would download %s\n" url;
-         let cmd = sprintf "{ curl %s %s | %s >> %s; }"
+         let cmd = sprintf "{ curl -L %s %s | %s >> %s; }"
            wquiet
            (escape_for_shell url)
            (Benl_compression.display_tool !Benl_clflags.preferred_compression_format)
@@ -101,7 +101,7 @@ let download_binaries arch =
     if r <> 0 then
       raise (Curl_error r)
     else
-      ignore (Sys.command (sprintf "rm -f %s" tmp))
+      FileUtil.rm ~force:FileUtil.Force [tmp]
   end;;
 
 let download_all architectures =
