@@ -17,15 +17,13 @@
 (*  <http://www.gnu.org/licenses/>.                                       *)
 (**************************************************************************)
 
-open Xhtml.M
+open Html5.M
 open Printf
 open Benl_core
 open Benl_clflags
 open Benl_utils
 open Benl_error
 
-module Arg = Benl_arg
-
 let ($) f x = f x
 
 let base = ref "."
@@ -38,6 +36,12 @@ let tconfig = ref None
 open Benl_types
 open Benl_frontend
 
+let eval x =
+  Query.eval
+    `source
+    (Package.of_assoc `source Benl_core.StringMap.empty)
+    (Query.of_expr x)
+
 let read_global_config () =
   if Sys.file_exists !global_config then begin
     let config = Benl_utils.parse_config_file !global_config in
@@ -64,12 +68,12 @@ let read_global_config () =
         | "mirror", (EString mirror) ->
           Benl_clflags.mirror_sources := mirror;
           Benl_clflags.mirror_binaries := mirror
-        | "use-cache", Etrue ->
-          Benl_clflags.use_cache := true
-        | "run-debcheck", Etrue ->
-          Benl_data.run_debcheck := true
-        | "use-projectb", Etrue ->
-          Benl_data.use_projectb := true
+        | "use-cache", expr ->
+          Benl_clflags.use_cache := eval expr
+        | "run-debcheck", expr ->
+          Benl_data.run_debcheck := eval expr
+        | "use-projectb", expr ->
+          Benl_data.use_projectb := eval expr
         | "base-url", (EString url) ->
           Ben_monitor.baseurl := url
         | "template", (EString template) ->
@@ -237,7 +241,7 @@ let print_html_collisions (hits : (SMap.key * SMap.key list) list) =
     in
     match List.rev hits with
     | [] -> pcdata "(none)"
-    | h::l -> ul h l
+    | h::l -> ul (h::l)
   ]
 
 let print_html_monitor config template file transition_data has_testing_data collisions =
@@ -424,10 +428,10 @@ let tracker template profiles =
       let tlist = List.map (tget show_score) tlist in
       match tlist with
         | [] -> acc
-        | h::l ->
+        | _::_ ->
           let tdiv = div ~a:[ a_class [ "transitions" ] ]
             [ b [ pcdata title ];
-              ul h l
+              ul tlist
             ] in
           tdiv::acc
     )
@@ -445,7 +449,9 @@ let tracker template profiles =
     Benl_error.error_exn "Failed to generate index.html" exn
 
 let () = at_exit (fun () ->
-  rm [lockf ()]
+  try
+    rm [lockf ()]
+  with _ -> ()
 )
 
 let main args =
